.. pynag documentation master file, created by
   sphinx-quickstart on Sun Mar 16 17:21:51 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pynag's documentation!
=================================
:Release: |version|
:Date: |today|


This document is under a `Creative Commons Attribution - Non-Commercial 
- Share Alike 2.5 <http://creativecommons.org/licenses/by-nc-sa/2.5/>`_ license.


.. toctree::
   :maxdepth: 3

   introduction
   pynag
